Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2444)

Unified Diff: chrome/browser/ui/views/toolbar_view.h

Issue 10630013: Adds LocationBarContainer that contains (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove set_view_to_focus Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/location_bar/location_bar_view.cc ('k') | chrome/browser/ui/views/toolbar_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/toolbar_view.h
diff --git a/chrome/browser/ui/views/toolbar_view.h b/chrome/browser/ui/views/toolbar_view.h
index a32fc135a48c464d1b1404b3e02c8d3ae405c5f1..6cdc0a37132b0780c08d8a9d47824b89cdbc095b 100644
--- a/chrome/browser/ui/views/toolbar_view.h
+++ b/chrome/browser/ui/views/toolbar_view.h
@@ -25,6 +25,7 @@
class BrowserActionsContainer;
class Browser;
+class LocationBarContainer;
class WrenchMenu;
namespace views {
@@ -46,10 +47,11 @@ class ToolbarView : public views::AccessiblePaneView,
explicit ToolbarView(Browser* browser);
virtual ~ToolbarView();
// Create the contents of the Browser Toolbar. |popup_parent_view| is the
// View to add the omnibox popup view to.
// TODO(sky): clearly describe when |popup_parent_view| is used.
- void Init(views::View* popup_parent_view);
+ void Init(views::View* location_bar_parent, views::View* popup_parent_view);
// Updates the toolbar (and transitively the location bar) with the states of
// the specified |tab|. If |should_restore_state| is true, we're switching
@@ -82,6 +84,9 @@ class ToolbarView : public views::AccessiblePaneView,
BrowserActionsContainer* browser_actions() const { return browser_actions_; }
ReloadButton* reload_button() const { return reload_; }
LocationBarView* location_bar() const { return location_bar_; }
+ LocationBarContainer* location_bar_container() const {
+ return location_bar_container_;
+ }
views::MenuButton* app_menu() const { return app_menu_; }
// Overridden from AccessiblePaneView
@@ -186,6 +191,10 @@ class ToolbarView : public views::AccessiblePaneView,
// unacknowledged background pages in the system.
gfx::ImageSkia GetBackgroundPageBadge();
+ // Sets the bounds of the LocationBarContainer. |bounds| is in the coordinates
+ // of |this|.
+ void SetLocationBarContainerBounds(const gfx::Rect& bounds);
+
scoped_ptr<BackForwardMenuModel> back_menu_model_;
scoped_ptr<BackForwardMenuModel> forward_menu_model_;
@@ -198,6 +207,7 @@ class ToolbarView : public views::AccessiblePaneView,
ReloadButton* reload_;
views::ImageButton* home_;
LocationBarView* location_bar_;
+ LocationBarContainer* location_bar_container_;
BrowserActionsContainer* browser_actions_;
views::MenuButton* app_menu_;
Browser* browser_;
@@ -46,10 +47,11 @@ class ToolbarView : public views::AccessiblePaneView,
explicit ToolbarView(Browser* browser);
virtual ~ToolbarView();
- // Create the contents of the Browser Toolbar. |popup_parent_view| is the
+ // Create the contents of the Browser Toolbar. |location_bar_parent| is the
+ // view the LocationBarContainer is added to. |popup_parent_view| is the
// View to add the omnibox popup view to.
// TODO(sky): clearly describe when |popup_parent_view| is used.
« no previous file with comments | « chrome/browser/ui/views/location_bar/location_bar_view.cc ('k') | chrome/browser/ui/views/toolbar_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698